@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2024 Maxime DOYEN
+ *  Copyright (C) 1995-2025 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -24,6 +24,9 @@
 #include "hb-preferences.h"
 #include "language.h"
 
+#include "ui-dialogs.h"
+#include "ui-widgets.h"
+
 #include <libsoup/soup.h>
 
 
@@ -220,8 +223,27 @@ gint i;
 
 
 /* = = = = = = = = = = = = = = = = = = = = */
-//5.7 test check update online
 
+static void
+homebank_util_check_backup(void)
+{
+	if( PREFS->bak_is_automatic == FALSE )
+		return;
+
+	if(! g_file_test(PREFS->path_hbbak, (G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)))
+	{
+
+		ui_dialog_msg_infoerror(GTK_WINDOW(GLOBALS->mainwindow), GTK_MESSAGE_ERROR,
+			_("Invalid Backup directory."),
+			_("The files backup will not work, directory is:\n'%s'."),
+				PREFS->path_hbbak
+			);
+	
+	}
+}
+
+
+//5.7 test check update online
 
 /*
 static gint homebank_util_check_update(GtkWindow *parent)
@@ -1024,8 +1046,7 @@ gchar *pathfilename;
 		g_free(ver_string);
 		*/
 
-		gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE, 0);
-		//gtk_box_pack_start (GTK_BOX (vbox), version, FALSE, FALSE, 0);
+		gtk_box_prepend (GTK_BOX (vbox), image);
 
 		gtk_window_set_auto_startup_notification (FALSE);
 		gtk_widget_show_all (window);
@@ -1105,7 +1126,7 @@ gint key;
 		}
 		l = g_list_next(l);
 	}
-
+	//no need to free glist
 	return window;
 }
 
@@ -1145,6 +1166,7 @@ gchar **remaining_args;
 		if( i > 0 )
 		{
 			arg_filepath = g_strdup(remaining_args[0]);
+			DB( g_print(" %s\n", arg_filepath) );
 		}
 
 		/*for (i = 0; remaining_args[i]; i++)
@@ -1170,11 +1192,10 @@ GtkWidget *splash = NULL;
 	DB( g_print("\n[homebank] app activate\n") );
 
 	//check if already a window opened
-	//TODO chnage here to enable multiple ?
 	if( GLOBALS->mainwindow != NULL )
 	{
+		//TODO change here to enable multiple ?
 		gtk_window_present (GTK_WINDOW (GLOBALS->mainwindow));
-	
 	}
 	else
 
@@ -1205,7 +1226,7 @@ GtkWidget *splash = NULL;
 			gtk_window_set_default_icon_name ("homebank");
 
 			DB( g_print(" app creating window\n" ) );
-			mainwin = (GtkWidget *)create_hbfile_window (NULL);
+			mainwin = (GtkWidget *)ui_wallet_window_new (NULL);
 			if(mainwin)
 			{
 			gchar *rawfilepath = NULL;
@@ -1230,24 +1251,28 @@ GtkWidget *splash = NULL;
 					DB( g_print(" command line open '%s'\n", arg_filepath ) );
 					rawfilepath = g_strdup(arg_filepath);
 					g_free (arg_filepath);
-					ui_mainwindow_open_check(mainwin, rawfilepath);
+					ui_wallet_open_check(mainwin, rawfilepath);
 				}
 				else
 				if( PREFS->showwelcome )
 				{
-					ui_mainwindow_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_VISUAL));
-					ui_mainwindow_action_help_welcome();
+					ui_wallet_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_VISUAL));
+					ui_wallet_action_help_welcome();
 				}
 				else
 				if( PREFS->loadlast )
 				{
 					rawfilepath = homebank_lastopenedfiles_load();
-					ui_mainwindow_open_check(mainwin, rawfilepath);
+					ui_wallet_open_check(mainwin, rawfilepath);
 				}
 				else
 					/* update the mainwin display */
-					ui_mainwindow_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_VISUAL));
+					ui_wallet_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_VISUAL));
 
+				//#2121204 check backup dir is reachable
+				#ifndef PORTABLE_APP
+				homebank_util_check_backup();
+				#endif
 
 				//5.7 test
 				//homebank_util_check_update(mainwin);
@@ -1292,9 +1317,10 @@ homebank_app_startup (GApplication *application)
 
 	DB( g_print("\n[homebank] app startup\n") );
 
-	#ifdef PORTABLE_APP
-	g_object_set (gtk_settings_get_default (), "gtk-recent-files-enabled", FALSE, NULL);
-	#endif	
+	//#2043886 
+	//#ifdef PORTABLE_APP
+	//g_object_set (gtk_settings_get_default (), "gtk-recent-files-enabled", FALSE, NULL);
+	//#endif	
 
 	GLOBALS->color_scheme = DEFAULT;
 	#ifdef G_OS_UNIX
